@@ -5,6 +5,7 @@ import json
 import time
 import logging
 import requests
+import pandas as pd
 from halo import Halo
 from urllib.request import urlopen
 from colorlog import ColoredFormatter
@@ -229,7 +230,7 @@ class InnocuousAPI:
                 return True
             time.sleep(10)
 
-    def get_experiment_result(self, id):
+    def get_best_experiment_config(self, id):
         """Get experiment result
         Args:
             id: Id of experiment
@@ -242,7 +243,7 @@ class InnocuousAPI:
         self._get_jwt_token()
         url = self.host + f"/api/experiment/result/{id}"
         r = self.session.get(url, headers=self.headers)
-        if r.status_code == 200 and json.loads(r.text)['result'] == 'ok':
+        if r.status_code == 200 and json.loads(r.text)['code'] == 0:
             result_url = json.loads(r.text)['data']['bestconfig']['path']
             f = urlopen(result_url)
             result_json = f.read()
@@ -251,6 +252,28 @@ class InnocuousAPI:
             self.log.info('request error, returning None')
             return None
 
+    def get_experiment_dataframe(self, id):
+        """Get experiment result
+        Args:
+            id: Id of experiment
+        Returns:
+            {
+                "code": 0,      # if success is 0
+                "data": data    # experiment result
+            }
+        """
+        self._get_jwt_token()
+        url = self.host + f"/api/experiment/result/{id}"
+        r = self.session.get(url, headers=self.headers)
+        if r.status_code == 200 and json.loads(r.text)['code'] == 0:
+            result_url = json.loads(r.text)['data']['dataframe']['path']
+            f = urlopen(result_url)
+            result_json = pd.read_pickle(f)
+            return json.loads(result_json)
+        else:
+            self.log.info('request error, returning None')
+            return None
+
     def kill_experiment(self, id):
         """Kill experiment
         Args:
